@@ -27,6 +27,8 @@ $message = array(
     'lang' => 'en',
     'strLang' => 'English',
 
+    'descAllow_sql_comments' => 'If on, ignore SQL comments when judging if load balance or query cache is possible',
+    'descApp_name_redirect_preference_list' => '"application name:node id" pairs to specify the node id when the application is used',
     'descArping_path' => 'The path of a command to send an ARP request after the virtual IP is switched',
     'descArping_cmd' => 'The ommand to send an ARP request after the virtual IP is switched',
     'descAuthentication_timeout' => 'Timeout in seconds to complete client authentication',
@@ -39,14 +41,18 @@ $message = array(
     'descDelegate_IP' => 'The virtual IP address (VIP) of pgpool-II ',
     'descBlack_function_list' => 'Comma separated functions which write to database',
     'descBlack_memqcache_table_list' => 'Comma separated list of table names not to be cached',
+    'descCheck_temp_table' => 'If on, enable temporary table check in SELECT statements',
     'descChild_life_time' => 'Life of an idle child process in seconds',
     'descChild_max_connections' => 'If child_max_connections connections were received, child exits',
+    'descClear_memqcache_on_escalation' => 'If on, watchdog clears all the query cache in the shared memory when pgpool-II escaltes to active',
     'descClient_idle_limit' => 'Timeout in seconds while waiting for a query from a client',
     'descClient_idle_limit_in_recovery' => 'Timeout in seconds while waiting for a query '.
                                            'from a client in on line recovery',
+    'descClient_min_messages' => 'Which minimum message levels are sent to the client',
     'descConnection_cache' => 'If true, cache connections to PostgreSQL',
     'descConnection_life_time' => 'Life time for each idle connection in seconds',
-    'descCheck_temp_table' => 'If on, enable temporary table check in SELECT statements',
+    'desCconnect_timeout' => 'Timeout value in milliseconds before giving up connecting to backend using connect() system call',
+    'descDatabase_redirect_preference_list' => '"database name:node id" pairs to specify the node id when connecting to the database',
     'descDelay_threshold' => 'If the standby server delays more than delay_threshold, '.
                              'any query goes to the primary only',
     'descDebug_level' => 'Debug message verbosity level',
@@ -58,6 +64,9 @@ $message = array(
                                                   'in UPDATE/DELETE',
     'descFail_over_on_backend_error' => 'Fail over when socket communication error to backend occurs',
     'descFollow_master_command' => 'Command to run only after a master failover',
+    'descHeartbeat_destination' => 'The destination of heartbeat signals. Specify by hostname or IP address.',
+    'descHeartbeat_destination_port' => 'The port number of the destination of heartbeat signals.',
+    'descHeartbeat_device' => 'The network device name for sending heartbeat signals',
     'descHealth_check_period' => 'Specifies the interval for next health checking. 0 means no health checking, '.
                                  '-1 means no wait',
     'descHealth_check_timeout' => 'Pgpool does "health check" periodically to detect PostgreSQL servers down, '.
@@ -68,17 +77,21 @@ $message = array(
                                       ' giving up and initiating failover',
     'descHealth_check_retry_delay' => 'The amount of time (in seconds) to sleep between failed health check retries',
     'descIfconfig_path' => 'The path of a command to switch the IP address',
-    'descIf_down_cmd' => 'The command to bring up the virtual IP',
-    'descIf_up_cmd' => 'The command to bring down the virtual IP',
+    'descIf_down_cmd' => 'The command to bring down the virtual IP',
+    'descIf_up_cmd' => 'The command to bring up the virtual IP',
     'descIgnore_leading_white_space' => 'If true, ignore leading white spaces of each query while pgpool judges '.
                                         'if the query is a SELECT so that it can be load balanced',
     'descInsert_lock' => ' If you replicate a table having SERIAL data type column, '.
                          'sometimes the serial value does not match between servers',
     'descListen_addresses' => 'Specifies the addresses to listen on for TCP/IP connections',
+    'descListen_backlog_multiplier' => 'The number of preforked pgpool-II server processes',
     'descLoad_balance_mode' => 'Perform load balancing for SELECT',
     'descLobj_lock_table' => 'Specifies table name lock used when rewriting lo_create in replication mode',
-    'descLog_destination' => 'Where to log',
     'descLog_connections' => 'If true, incoming connections will be printed to the log',
+    'descLog_destination' => 'Where to log',
+    'descLog_error_verbosity' => 'The amount of detail emitted for each message that is logged',
+    'descLog_line_prefix' => 'printf-style string that is output at the beginning of each log line',
+    'descLog_min_messages' => 'Which minimum message levels are emitted to log',
     'descLog_standby_delay' => 'Frequency to log the standby delay',
     'descLog_hostname' => 'If true, client\'s hostname will be shown in ps status and in a connection log '.
                           'if log_connections is true',
@@ -124,7 +137,8 @@ $message = array(
     'descReplication_mode' => 'Set this to true if you are going to use replication functionality',
     'descReplication_stop_on_mismatch' => 'Stop replication mode on data mismatch between master and secondary',
     'descReplicate_select' => 'If true, replicate SELECT queries. If false, send only to master',
-    'descReplication_timeout' => 'In non strict replication mode, there will be a risk of deadlock. Timeout in second for monitoring the deadlock',
+    'descReplication_timeout' => 'In non strict replication mode, there will be a risk of deadlock. '.
+                                 'Timeout in second for monitoring the deadlock',
     'descReset_query_list' => 'Semicolon separated SQL commands to be issued at the end of session',
     'descSsl' => 'The frontend connection',
     'descSsl_ca_cert' => 'Path to the SSL private key file',
@@ -145,10 +159,19 @@ $message = array(
     'descSystem_db_user' => 'The username when connection system database',
     'descTrusted_servers' => 'The list of trusted servers to check the up stream connections',
     'descUse_watchdog' => 'Enable watchdog',
+    'descWd_authkey' => 'The authentication key used in watchdog communication',
+    'descWd_escalation_command' => 'The command which will be executed on the new active when pgpool-II escaltes to active',
+    'descWd_heartbeat_deadtime' => 'If there are no heartbeat signal for the period specified by this option, watchdog regards it as failure of the remote pgpool-II.',
+    'descWd_heartbeat_keepalive' => 'The interval time of sending heartbeat signals in seconds',
+    'descWd_heartbeat_port' => 'The port number to receive heartbeat signals',
     'descWd_hostname' => 'The hostname or IP address in which pgpool-II works',
     'descWd_interval' => 'The interval between life checks of pgpool-II in second',
     'descWd_life_point' => 'The times to retry a failed life check of pgpool-II',
+    'descWd_lifecheck_dbname' => 'The database name connected for checking pgpool-II',
+    'descWd_lifecheck_method' => 'The method of life check',
     'descWd_lifecheck_query' => 'Actual query to check pgpool-II',
+    'descWd_lifecheck_password' => 'The user name to check pgpool-II',
+    'descWd_lifecheck_user' => 'The password of the user to check pgpool-II',
     'descWd_port' => 'The port number on which pgpool-II works',
     'descWhite_function_list' => 'Comma separated functions those do not write to Database',
     'descWhite_memqcache_table_list' => 'Comma separated list of table names to be cached',
@@ -169,7 +192,10 @@ $message = array(
     'errShouldBeZeroOrMore' => 'This should be 0 or more',
     'errSingleQuotation' => 'Please enclose the array element with a single quotation.',
 
+    'msgAddBackend' => 'Do you really add this node as a new backend?',
+    'msgAddBackendNg' => 'Invalid.',
     'msgDeleteConfirm' => 'Do you really want to delete it?',
+    'msgHasNotLoadedNode' => 'You have to reload pgpool to use the new backend node.',
     'msgMasterDbConnectionError' => 'Master DB connection failed',
     'msgPgpoolConfNotFound' => 'pgpool.conf not found',
     'msgPleaseSetup' => 'No found configuration file. Please execute the setup.',
@@ -178,15 +204,20 @@ $message = array(
     'msgRestartPgpool' => 'Do you really want to restart pgpool?',
     'msgSameAsPasswordFile' => 'The value is the same as item Password File',
     'msgSameAsPgpoolFile' => 'The value is the same as item pgpool.conf File',
+    'msgStartPgpool' => 'Do you really start pgpool?',
     'msgStopPgpool' => 'Do you really want to stop pgpool?',
     'msgUpdateComplete' => 'Update complete',
+    'msgUpdateCompleteInfo' => 'You have to reload or restart pgpool to use new configuration.',
     'msgUpdateFailed' => 'Update failed',
     'msgDetachConfirm' => 'Do you really detach this node?',
     'msgReturnConfirm' => 'Do you really make this node return?',
     'msgRecoveryConfirm' => 'Do you really recover this node?',
+    'msgRemoveBackend' => 'Do you really remove this backend node?',
     'msgRPromoteConfirm' => 'Do you really make this node primary?',
 
     'strAdd' => 'Add',
+    'strAddBackend' => 'Add a new backend node',
+    'strAddBackendNow' => 'Reload pgpool right after adding',
     'strAdminPassword' => 'Password',
     'strBack' => 'Back',
     'strBackendPid' => 'Backend Pid',
@@ -238,7 +269,13 @@ $message = array(
     'strLog' => 'Log',
     'strLogin' => 'Login',
     'strLoginName' => 'Login Name',
+    'strLogLatest' => 'Show the Latest',
+    'strLogNext' => 'Next',
     'strLogout' => 'Logout',
+    'strLogPrev' => 'Previous',
+    'strLogReload' => 'Reload',
+    'strLogShowAll' => 'Show the All Lines',
+    'strLogShowLines' => 'Lines',
     'strMasterServer' => 'Master Server',
     'strMasterSlaveMode' => 'Master Slave mode',
     'strMeasures' => 'Measures',
@@ -284,11 +321,15 @@ $message = array(
     'strQueryCache' => 'Query Cache',
     'strQueryStr' => 'Query',
     'strReloadPgpool' => 'Reload',
+    'strReloadPgsql' => 'Reload',
     'strReplicationMode' => 'Replication Mode',
     'strReset' => 'Reset',
     'strRestart' => 'Restart',
     'strRestartOption' => 'pgpool Restart Option',
     'strRestartPgpool' => 'Restart pgpool',
+    'strRestartPgsql' => 'Restart',
+    'strRestartPgsqlOption' => 'Restart PostgreSQL Option',
+    'strRemoveBackend' => 'Remove',
     'strReturn' => 'Return',
     'strRecovery' => 'Recovery',
     'strSchemaName' => 'Schema Name',
@@ -300,18 +341,30 @@ $message = array(
     'strStandbyRunning' => 'Running as standby server',
     'strStartOption' => 'Start Option',
     'strStartPgpool' => 'Start pgpool',
+    'strStartPgsql' => 'Start',
     'strStatus' => 'Status',
     'strStopOption' => 'pgpool Stop Option',
     'strStopPgpool' => 'Stop pgpool',
+    'strStopPgsql' => 'Stop',
+    'strStopPgsqlOption' => 'Stop PostgreSQL Option',
+    'strStoppingNow' => 'Not Running',
     'strStreamingRepMode' => 'Streaming Replication mode',
     'strSummary' => 'Summary',
     'strSystemDb' => 'Partitioning Rule',
+    'strSystemCatalog' => 'System catalog',
     'strTable' => 'Table',
+    'strTrustedServers' => 'List of Upstream Servers',
     'strTypeList' => 'Type List of Column',
     'strUp' => 'Up',
     'strUpdate' => 'Update',
+    'strUnknown' => 'Unknown',
     'strValue' => 'Value',
     'strVersion' => 'pgpool-II version',
+    'strVIP' => 'Virtual IP',
+    'strWdActive' => 'Active',
+    'strWdDown' => 'Down',
+    'strWdInit' => 'Not Started',
+    'strWdStandby' => 'Standby',
     'strWeight' => 'Weight',
 
     'e1' => 'pgmgt.conf.php not found.',
