@@ -27,6 +27,8 @@ $message = array(
     'lang' => 'ja',
     'strLang' => '日本語',
 
+    'descAllow_sql_comments' => '負荷分散やクエリキャッシュができるかどうかの判定の際に、SQLコメントを無視するかどうか',
+    'descApp_name_redirect_preference_list' => 'アプリケーション名によって負荷分散をしたいノード番号を、"アプリケーション名:ノード番号"で指定',
     'descArping_path' => 'IP アドレス切り替え後に ARP リクエストを送信するコマンドのパス',
     'descArping_cmd' => 'IP アドレス切り替え後に ARP リクエストを送信するコマンド',
     'descAuthentication_timeout' => 'クライアント認証のタイムアウト時間(秒)',
@@ -41,10 +43,14 @@ $message = array(
     'descCheck_temp_table' => '一時テーブルかどうかをチェック',
     'descChild_life_time' => 'pgpoolの子プロセスの寿命',
     'descChild_max_connections' => '各pgpool子プロセスが終了するまでの接続回数',
+    'descClear_memqcache_on_escalation' => 'アクティブ昇格時に共有メモリ上のクエリキャッシュを削除するかどうか',
     'descClient_idle_limit' => 'クライアントからのクエリの最大待ち時間(秒)',
     'descClient_idle_limit_in_recovery' => 'リカバリ中のクライアントからのクエリの最大待ち時間(秒)',
+    'descClient_min_messages' => 'クライアントに送るログの詳細レベル',
     'descConnection_cache' => 'コネクションキャッシュ機能の有無',
     'descConnection_life_time' => 'コネクションプール中のコネクションの有効期間(秒)',
+    'desCconnect_timeout' => 'connect()システムコールを使ってバックエンドに接続する際のタイムアウト値を指定（ミリ秒）',
+    'descDatabase_redirect_preference_list' => 'データベース名によって負荷分散をしたいノード番号を、"データベース名:ノード番号"で指定',
     'descDebug_level' => 'デバッグメッセージの詳細レベル（0は無効）',
     'descDelay_threshold' => '許容するスタンバイサーバの遅延(バイト)',
     'descDelegate_IP' => '仮想 IP アドレス',
@@ -55,6 +61,9 @@ $message = array(
     'descFailover_if_affected_tuples_mismatch' => '更新行数が一致しないときにフェイルオーバ',
     'descFail_over_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
     'descFollow_master_command' => 'マスタのフェイルオーバ後に実行するコマンド',
+    'descHeartbeat_destination' => 'ハートビート信号の送信先ホスト名または IP アドレス',
+    'descHeartbeat_destination_port' => 'ハートビート信号の送信先ポート番号',
+    'descHeartbeat_device' => 'ハートビートの送受信に用いるネットワークデバイス名',
     'descHealth_check_period' => 'ヘルスチェックを行う間隔(秒)',
     'descHealth_check_timeout' => 'ヘルスチェックが長時間待たされるのを防ぐためのタイムアウト値(秒)',
     'descHealth_check_user' => 'ヘルスチェックを行うためのPostgreSQLユーザ名',
@@ -67,11 +76,15 @@ $message = array(
     'descIgnore_leading_white_space' => 'load balance時のSQL文行頭の空白を無視',
     'descInsert_lock' => 'INSERT時に自動的にトランザクションの開始，テーブルロック，トランザクションの終了',
     'descListen_addresses' => 'TCP/IPコネクションを受け付けるアドレス',
+    'descListen_backlog_multiplier' => 'フロントエンドからpgpool-IIへの接続待ち行列の長さ',
     'descLoad_balance_mode' => 'レプリケーションモード時にSELECT文を各ノードにロードバランス',
     'descLobj_lock_table' => 'ラージオブジェクトのレプリケーションでロック管理に使うためのテーブル名',
     'descLog_connections' => '受信した接続のログを出力',
     'descLog_destination' => 'ログの出力先',
+    'descLog_error_verbosity' => '出力するログの詳細レベル',
     'descLog_hostname' => 'クライアントのホスト名を"ps"ステータスに出力',
+    'descLog_line_prefix' => '各ログ行頭の出力形式',
+    'descLog_min_messages' => 'ログとして記録するログの詳細レベル',
     'descLog_standby_delay' => 'スタンバイサーバの遅延をログに記録する',
     'descLog_statement' => 'SQL文をログ出力',
     'descLogdir' => 'pgpoolの各種ログファイルを格納するディレクトリ',
@@ -137,10 +150,19 @@ $message = array(
     'descSystem_db_user' => 'System DBに接続するときのユーザ名',
     'descTrusted_servers' => '上位サーバのコンマ区切りのリスト',
     'descUse_watchdog' => 'watchdog 機能の有無',
+    'descWd_authkey' => 'wachdog 間通信で用いられる認証キー',
+    'descWd_escalation_command' => 'アクティブ昇格時に実行するコマンド',
+    'descWd_heartbeat_deadtime' => '障害発生とみなすまでの猶予（秒）',
+    'descWd_heartbeat_keepalive' => 'ハートビート信号を送信する間隔（秒）',
+    'descWd_heartbeat_port' => 'ハートビート信号を受信するポート番号',
     'descWd_hostname' => 'watchdog プロセスが相互監視を受信するためのホスト名',
     'descWd_interval' => '死活監視の間隔(秒)',
     'descWd_life_point' => '死活監視のリトライ回数',
+    'descWd_lifecheck_dbname' => '死活監視を行なうために接続するデータベース',
+    'descWd_lifecheck_method' => '死活監視の方法',
     'descWd_lifecheck_query' => '死活監視で実行するクエリ',
+    'descWd_lifecheck_password' => '死活監視を行なうユーザのパスワード',
+    'descWd_lifecheck_user' => '死活監視を行なうユーザ',
     'descWd_port' => 'watchdog プロセスが相互監視を受信するためのポート番号',
     'descWhite_function_list' => 'データベースに書き込みを行なわないカンマ区切りの関数のリスト',
     'descWhite_memqcache_table_list' => 'SELECT結果をキャッシュしたいテーブル名のカンマ区切りのリスト',
@@ -161,7 +183,10 @@ $message = array(
     'errShouldBeZeroOrMore' => '0以上である必要があります',
     'errSingleQuotation' => '配列要素をシングルクォーテーションで囲んでください。',
 
+    'msgAddBackend' => 'バックエンドノードとして追加してよろしいですか？',
+    'msgAddBackendNg' => 'バックエンドノード情報に不備があります。',
     'msgDeleteConfirm' => '本当に削除してよいですか？',
+    'msgHasNotLoadedNode' => '新しいノード情報を読み込むには pgpool の設定をリロードする必要があります。',
     'msgMasterDbConnectionError' => 'マスターDBに接続できません',
     'msgPgpoolConfNotFound' => 'pgpool.confが見つかりません',
     'msgPleaseSetup' => '設定ファイルが見つかりません。セットアップを実行してください。',
@@ -170,15 +195,20 @@ $message = array(
     'msgRestartPgpool' => 'pgpoolを再起動してよろしいですか？',
     'msgSameAsPasswordFile' => '値はパスワードファイルの設定値となります',
     'msgSameAsPgpoolFile' => '値はpgpool.confファイルの設定値となります',
-    'msgStopPgpool' => 'pgpoolを停止してよいですか？',
-    'msgUpdateComplete' => '更新は正常に終了しました',
-    'msgUpdateFailed' => '更新に失敗しました',
-    'msgDetachConfirm' => 'このノードを切断してよいですか？',
-    'msgReturnConfirm' => 'このノードを復帰させてよいですか？',
+    'msgStartPgpool' => 'pgpoolを起動しますか？',
+    'msgStopPgpool' => 'pgpoolを停止してよろしいですか？',
+    'msgUpdateComplete' => '更新は正常に終了しました。',
+    'msgUpdateCompleteInfo' => '設定を反映するには、pgpoolの設定リロードか再起動をする必要があります。',
+    'msgUpdateFailed' => '更新に失敗しました。',
+    'msgDetachConfirm' => 'このノードを pgpool-II の管理から切断してよいですか？',
+    'msgReturnConfirm' => 'このノードを pgpool-II の管理下に復帰させてよいですか？',
     'msgRecoveryConfirm' => 'このノードをリカバリしますか？',
+    'msgRemoveBackend' => 'このバックエンドノードを削除してよろしいですか？',
     'msgRPromoteConfirm' => 'このノードをマスタに昇格しますか？',
 
     'strAdd' => '追加',
+    'strAddBackend' => '新しいバックエンドを登録',
+    'strAddBackendNow' => '即座に追加する（pgpool の設定をリロードします）',
     'strAdminPassword' => '管理者パスワード',
     'strBack' => '戻る',
     'strBackendPid' => 'バックエンドプロセスID',
@@ -230,7 +260,13 @@ $message = array(
     'strLog' => 'ログ',
     'strLogin' => 'ログイン',
     'strLoginName' => 'ログイン名',
+    'strLogLatest' => '最新',
+    'strLogNext' => '次へ',
     'strLogout' => 'ログアウト',
+    'strLogPrev' => '前へ',
+    'strLogReload' => '更新',
+    'strLogShowAll' => '全ての行を表示',
+    'strLogShowLines' => '行を表示',
     'strMasterServer' => 'マスターサーバ',
     'strMasterSlaveMode' => 'マスタースレーブモード',
     'strMeasures' => '対策',
@@ -276,34 +312,50 @@ $message = array(
     'strQueryCache' => 'クエリキャッシュ',
     'strQueryStr' => 'クエリ文字列',
     'strReloadPgpool' => '設定リロード',
+    'strReloadPgsql' => '設定リロード',
     'strReplicationMode' => 'レプリケーションモード',
     'strReset' => 'リセット',
     'strRestart' => '再起動',
     'strRestartOption' => 'pgpool再起動オプション',
     'strRestartPgpool' => 'pgpool再起動',
+    'strRestartPgsql' => '再起動',
+    'strRestartPgsqlOption' => 'PostgreSQL再起動オプション',
+    'strRemoveBackend' => '登録削除',
     'strReturn' => '復帰',
     'strRecovery' => 'リカバリ',
     'strSchemaName' => 'スキーマ名',
     'strSearch' => '検索',
     'strSecondaryServer' => 'セカンダリサーバ',
-    'strSetting' => '管理ツール設定',
+    'strSetting' => 'pgpoolAdmin設定',
     'strSetup' => 'セットアップ',
     'strSlonyMode' => 'Slony-Iモード',
     'strStandbyRunning' => 'スタンバイとして稼働中',
     'strStartOption' => '起動オプション',
     'strStartPgpool' => 'pgpool起動',
+    'strStartPgsql' => '起動',
     'strStatus' => 'ステータス',
     'strStopOption' => 'pgpool停止オプション',
     'strStopPgpool' => 'pgpool停止',
+    'strStopPgsql' => '停止',
+    'strStopPgsqlOption' => 'PostgreSQL停止オプション',
+    'strStoppingNow' => '停止中',
     'strStreamingRepMode' => 'Streaming Replicationモード',
     'strSummary' => '概要',
     'strSystemDb' => '分散ルール',
+    'strSystemCatalog' => 'システムカタログ情報',
     'strTable' => 'テーブル名',
+    'strTrustedServers' => '上位サーバリスト',
     'strTypeList' => '列データ型リスト',
     'strUp' => 'アップ',
     'strUpdate' => '更新',
+    'strUnknown' => '不明',
     'strValue' => '値',
     'strVersion' => 'pgpool-II バージョン',
+    'strVIP' => '仮想IP',
+    'strWdActive' => 'アクティブ',
+    'strWdDown' => 'ダウン',
+    'strWdInit' => '未起動',
+    'strWdStandby' => 'スタンバイ',
     'strWeight' => 'ウェイト',
 
     'e1' => 'pgmgt.conf.phpが見つかりません',
